from setuptools import setup

setup(name='cris_distribution_test_package',
      version='1.9',
      description='Gaussian and binomial distributions',
      packages=['distributions'],
      zip_safe=False)
